<?php

class formWidgetContentRandomitemOptions extends cmsForm {

    public function init($options=false) {

	    $content_model = cmsCore::getModel('content');

        $field_generator = function ($item, $request) use($content_model) {
            $list     = ['' => ''];
            $ctype_id = is_array($item) ? array_value_recursive('options:ctype_id', $item) : false;
            if (!$ctype_id && $request) {
                $ctype_id = $request->get('options:ctype_id', 0);
            }
            if (!$ctype_id) {
                return $list;
            }
            $ctype = $content_model->getContentType($ctype_id);
            if (!$ctype) {
                return $list;
            }
            $fields = $content_model->getContentFields($ctype['name']);
            if ($fields) {
                $list = $list + array_collection_to_list($fields, 'name', 'title');
            }
            return $list;
        };

        return array(	
            array(
                'type' => 'fieldset',
                'title' => 'Настройки рандома',
                'childs' => array(
                    new fieldString('options:id', array(
                        'title'     => 'Уникальный идентификатор',
                        'hint' => 'Напрмимер <strong>my-random</strong>. Идентификатор не может начинаться с цифп, а также должен состоять только из латинских букв и цифр.',
                        'rules' => array(
                            array('required')
                        )
                    )),
                    new fieldList('options:ctype_id', array(
                        'title'     => 'Тип контента',
                        'generator' => function($ctype) use($content_model) {
                            $tree = $content_model->getContentTypes();
                            $items = array(0 => 'Определять автоматически');
                            if ($tree) {
                                foreach ($tree as $item) {
                                    $items[$item['id']] = $item['title'];
                                }
                            }
                            return $items;
                        },
                    )),
                    new fieldList('options:category_id', array(
                        'title'     => 'Категория',
                        'parent'    => array(
                            'list' => 'options:ctype_id',
                            'url'  => href_to('content', 'widget_cats_ajax')
                        ),
                        'generator' => function($item, $request) use($content_model) {
                            $list     = ['' => ''];
                            $ctype_id = is_array($item) ? array_value_recursive('options:ctype_id', $item) : false;
                            if (!$ctype_id && $request) {
                                $ctype_id = $request->get('options:ctype_id', 0);
                            }
                            if (!$ctype_id) {
                                return $list;
                            }
                            $ctype = $content_model->getContentType($ctype_id);
                            if (!$ctype) {
                                return $list;
                            }
                            $cats = $content_model->getCategoriesTree($ctype['name']);
                            if ($cats) {
                                foreach ($cats as $cat) {
                                    if ($cat['ns_level'] > 1) {
                                        $cat['title'] = str_repeat('-', $cat['ns_level']) . ' ' . $cat['title'];
                                    }
                                    $list[$cat['id']] = $cat['title'];
                                }
                            }
                            return $list;
                        },
                        'visible_depend' => array('options:ctype_id' => array('hide' => array('0')))
                    )),
                    new fieldList('options:dataset', array(
                        'title'     =>  'Название набора',
                        'parent'    => array(
                            'list' => 'options:ctype_id',
                            'url'  => href_to('content', 'widget_datasets_ajax')
                        ),
                        'generator' => function($item, $request) use($content_model) {
                            $list     = ['0' => ''];
                            $ctype_id = is_array($item) ? array_value_recursive('options:ctype_id', $item) : false;
                            if (!$ctype_id && $request) {
                                $ctype_id = $request->get('options:ctype_id', 0);
                            }
                            if (!$ctype_id) {
                                return $list;
                            }
                            $datasets = $content_model->getContentDatasets($ctype_id);
                            if ($datasets) {
                                $list = $list + array_collection_to_list($datasets, 'id', 'title');
                            }
                            return $list;
                        },
                        'visible_depend' => array('options:ctype_id' => array('hide' => array('0')))
                    )),
                    new fieldList('options:image_field', array(
                        'title' => 'Поле изображения',
                        'rules' => array(
                            array('required')
                        ),
						'parent' => array(
							'list' => 'options:ctype_id',
							'url' => href_to('content', 'widget_fields_ajax')
						),
						'generator' => $field_generator
                    )),
                    
                    new fieldList('options:image_preset', array(
                        'title' => 'Пресет изображения',
                        'generator' => function($item) {
                            return cmsCore::getModel('images')->getPresetsList(true)+array('original' => LANG_PARSER_IMAGE_SIZE_ORIGINAL);
                        },
                    )),
                    new fieldList('options:teaser_field', array(
                        'title' => 'Поле краткого описания',
						'parent' => array(
							'list' => 'options:ctype_id',
							'url' => href_to('content', 'widget_fields_ajax')
						),
						'generator' => $field_generator
                    )),
                    new fieldNumber('options:limit', array(
                        'title' => 'Записей в рандоме',
                        'default' => 4,
                        'units' => 'шт',
                        'rules' => array(
                            array('required')
                        )
                    )),
                    new fieldNumber('options:delay_random', array(
                        'title' => 'Сколько секунд показывать одну запись?',
                        'default' => 6,
                        'units' => 'сек',
                        'rules' => array(
                            array('required')
                        )
                    )),
                    new fieldNumber('options:period_random', array(
                        'title' => 'Интервал между показом записей',
                        'hint' => 'Интервал между записями. Инетрвал также будет учтен перед показом первой рандомной записи',
                        'default' => 3,
                        'units' => 'сек',
                        'rules' => array(
                            array('required')
                        )
                    ))
                )
            ),
            array(
                'type' => 'fieldset',
                'title' => 'Настройка внешнего вида',
                'childs' => array(
                    new fieldList('options:x_pos', array(
                        'title' => 'Положение по горизонтали',
                        'hint' => 'Укажите, с какой стороны должно отображаться окно',
                        'items' => array(
                            'left' => 'Слева',
                            'right' => 'Справа'
                        ),
                        'default' => 'left'
                    )),
                    new fieldList('options:y_pos', array(
                        'title' => 'Положение по вертикали',
                        'hint' => 'Укажите, где должно отображаться окно - сверху или снизу',
                        'items' => array(
                            'top' => 'Сверху',
                            'bottom' => 'Снизу'
                        ),
                        'default' => 'bottom'
                    )),
                    new fieldNumber('options:random_width', array(
                        'title' => 'Ширина окна с рандомной записью',
                        'hint' => 'Не меняйте значение по умолчанию, если не уверены!',
                        'units' => '%',
                        'default' => 30
                    )),
                    new fieldString('options:random_bg', array(
                        'title' => 'Фон окна',
                        'hint' => 'Укажите здесь значение в формате RGBA',
                        'default' => '0, 0, 0, 0.8'
                    )),
                    new fieldNumber('options:random_radius', array(
                        'title' => 'Закругление углов окна',
                        'hint' => 'Если не требуется, укажите 0',
                        'units' => 'px',
                        'default' => 20
                    )),
                    new fieldColor('options:t_color', array(
                        'title' => 'Цвет заголовка записи',
                    )),
                    new fieldColor('options:teaser_color', array(
                        'title' => 'Цвет текста краткого описания',
                    )),
                    new fieldCheckbox('options:show_title', array(
                        'title' => 'Включить заголовок',
                        'hint' => 'Если включить этот чекбокс, то у всплывающих окон отобразится заголовок',
                        'default' => false
                    )),
                    new fieldString('options:title_t', array(
                        'title' => 'Отображаемый заголовок',
                        'default' => 'Случайная запись',
                        'visible_depend' => array('options:show_title' => array('show' => array('1')))
                    )),
                )
            )
        );

    }
}
